@@ -1,12 +1,12 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-04 10:58:54
-# @Last Modified time: 2020-06-17 21:08:15
+# @Last Modified time: 2020-10-22 16:34:03
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
-from pydbapi.api import SqliteDB, RedshiftDB, MysqlDB
+from pydbapi.api import SqliteDB, RedshiftDB, MysqlDB, SnowflakeDB
 
-__all__ = ['SqliteDB', 'RedshiftDB', 'MysqlDB']
+__all__ = ['SqliteDB', 'RedshiftDB', 'MysqlDB', 'SnowflakeDB']
