@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-02 18:46:58
-# @Last Modified time: 2020-08-11 19:16:58
+# @Last Modified time: 2020-10-22 18:32:24
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -88,9 +88,9 @@ class DBbase(object):
             comment, sql, action, tablename = parser.comment, parser.sql, parser.action, parser.tablename
             step = f"【{idx}】({action}){tablename}::{comment}"
             if verbose:
-                dblogger.info(f"Start {step}")
+                dblogger.info(f"Start::{step}")
             else:
-                sqls.postfix[0] = step
+                sqls.postfix[0] = f"{step}"
                 sqls.update()
 
             self.__execute_step(cur, sql)
@@ -163,6 +163,7 @@ class DBCommon(DBbase):
         sql = f"select * from {tablename} limit 1;"
         rows, action, result = self.execute(sql)
         columns = result[0]
+        columns = [c.lower() for c in columns]
         return columns
 
     def select(self, tablename, columns, condition=None):
@@ -191,9 +192,3 @@ class DBCommon(DBbase):
         rows, action, result = self.execute(sql_for_select)
         return rows, action, result
 
-
-
-
-
-
-
